/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Unity 0.1
import Utils 0.1

UbuntuShape {
    id: bubble

    property alias iconSource: avatarIcon.source
    property alias summary: summaryLabel.text
    property alias body: bodyLabel.text
    property var actions
    property bool snapDecision: actions != null
    property alias secondaryIconSource: secondaryIcon.source

    color: "black"
    opacity: 0.85
    width: parent.width
    height: childrenRect.height + units.gu (1)
    Behavior on opacity {NumberAnimation{}}

    UbuntuShape {
        id: icon

        anchors {
            left: parent.left
            leftMargin: units.gu(1)
            top: parent.top
            topMargin: units.gu(1)
        }

        width: units.gu (6)
        height: units.gu (6)
        image: Image {
            id: avatarIcon
            fillMode: Image.PreserveAspectCrop
        }
    }
    Image {
        id: secondaryIcon

        anchors {
            left: parent.left
            leftMargin: units.gu(8)
            top: parent.top
            topMargin: units.gu(1)
        }

        visible: secondaryIconSource ? true : false
        width: units.gu (2)
        height: units.gu (2)
        fillMode: Image.PreserveAspectCrop
    }
    Label {
        id: summaryLabel

        anchors {
            left: parent.left
            leftMargin: secondaryIcon.visible ? units.gu(11) : units.gu(8)
            top: parent.top
            topMargin: units.gu(1)
        }

        width: secondaryIcon.visible ? units.gu (25) : units.gu (28)
        font.family: "Ubuntu"
        fontSize: "medium"
        color: "#f3f3e7"
        opacity: 1.0
        maximumLineCount: 1
        elide: Text.ElideRight
    }
    Label {
        id: bodyLabel

        anchors {
            left: parent.left
            leftMargin: secondaryIcon.visible ? units.gu(11) : units.gu(8)
            top: parent.top
            topMargin: units.gu(3)
        }

        width: secondaryIcon.visible ? units.gu (25) : units.gu (28)
        font.family: "Ubuntu"
        fontSize: "small"
        color: "#f3f3e7"
        opacity: 0.6
        wrapMode: Text.WordWrap
        maximumLineCount: 10
    }

    Component {
        id: snapDecisionButtons

        Row {
            visible: snapDecision
            spacing: units.gu (1)

            parent: bubble

            anchors {
                left: parent.left
                leftMargin: units.gu (1)
                top: (icon.height >= summaryLabel.height + bodyLabel.height) ? icon.bottom : bodyLabel.bottom
                topMargin: snapDecision ? units.gu (1) : 0
            }

            Button {
                id: cancalButton
                visible: snapDecision

                width: units.gu (17.5)
                height: units.gu (4)
                text: actions.get(1).action_label
                onClicked: print("clicked " + actions.get(1).action_id)
            }

            Button {
                id: acceptlButton
                visible: snapDecision

                color: "#d85317"
                width: units.gu (17.5)
                height: units.gu (4)
                text: actions.get(0).action_label
                onClicked: print("clicked " + actions.get(0).action_id)
            }
        }
    }

    Loader {
        sourceComponent: snapDecision ? snapDecisionButtons : undefined
    }
}
